@@ -35,6 +35,10 @@ realtime_quote = "https://stock.xueqiu.com/v5/stock/realtime/quotec.json?symbol=
 realtime_pankou = "https://stock.xueqiu.com/v5/stock/realtime/pankou.json?symbol="
 realtime_quote_detail = "https://stock.xueqiu.com/v5/stock/quote.json?extend=detail&symbol="
 
+# kline
+
+kline = "https://stock.xueqiu.com/v5/stock/chart/kline.json?symbol={}&begin={}&period=day&type=before&count=-{}&indicator=kline,pe,pb,ps,pcf,market_capital,agt,ggt,balance"
+
 # user
 watch_list = "https://stock.xueqiu.com/v5/stock/portfolio/list.json?system=true"
 watch_stock = "https://stock.xueqiu.com/v5/stock/portfolio/stock/list.json?size=1000&category=1&pid="
